==> getfem-matlab-1.1.tar.gz: getfem-matlab-1.1/matlabint/matlabint_poly.h <==
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_poly.h : polynomials management.                    */
/*     									   */
/*                                                                         */
/* Date : October 10, 2001.                                                */
/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard.                                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef __MATLABINT_MESH_H
#define __MATLABINT_MESH_H

#include <matlabint.h>
#include <bgeot_config.h>
#include <bgeot_poly.h>

namespace matlabint
{
  int new_poly(void);
  void del_poly(int i);
  bgeot::base_poly &poly(int i);
  bool exists_poly(int i);
  void clear_all_poly(void);
  
}  /* end of namespace matlabint.                                          */

#endif /* __MATLABINT_MESH_H                                               */

==> getfem-matlab-1.3.tar.gz: getfem-matlab-1.3/matlabint/matlabint_poly.h <==
/* -*- c++ -*- (enables emacs c++ mode)                                    */
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_poly.h : polynomials management.                    */
/*     									   */
/*                                                                         */
/* Date : October 10, 2001.                                                */
/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard.                                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef __MATLABINT_POLY_H
#define __MATLABINT_POLY_H

#include <matlabint_std.h>
#include <bgeot_config.h>
#include <bgeot_poly.h>
#include <matlabint_object.h>

namespace matlabint
{
  class matlabint_poly : public getfem_object {
  private:
    bgeot::base_poly *p;
    
  public:
    matlabint_poly() { 
      p = new bgeot::base_poly();
    }
    ~matlabint_poly() {
      delete p;
    }
    std::string type_name() const { return "poly"; }

    bgeot::base_poly& poly() { return *p; }
    const bgeot::base_poly& poly() const { return *p; }
  };

  inline bool object_is_poly(getfem_object *o) {
    return (o->type_name().compare("poly")==0);
  }

  inline matlabint_poly* object_to_poly(getfem_object *o) {
    if (object_is_poly(o)) return ((matlabint_poly*)o);
    else THROW_INTERNAL_ERROR;
  }
}  /* end of namespace matlabint.                                          */

#endif /* __MATLABINT_POLY_H                                               */
